@@ -1,7 +1,7 @@
 import enum
-from typing import List, Union, Dict
-from datetime import datetime
 from dataclasses import dataclass
+from datetime import datetime
+from typing import Dict, List, Union
 
 
 @dataclass
