@@ -1,9 +1,10 @@
 import os
-from requests import Response
-from typing import List, Union, Dict
-from .models import EmbeddedMessage, Color
+from typing import Dict, List, Union
 
-from discord_webhook import DiscordWebhook, DiscordEmbed
+from discord_webhook import DiscordEmbed, DiscordWebhook
+from requests import Response
+
+from .models import Color, EmbeddedMessage
 
 
 class BotDiscordPlugin:
